/*
  Persistence of Vision Ray Tracer Scene Description File
  --
  BAMBOO
  --   
  Jaime Vives Piqueres, May 2011

*/

// ****************
// control switches
// ****************
#declare use_blur=10;
#declare use_area=1;  
#declare use_rad=1;  
#declare field_width=50;


// ***************
// global settings
// ***************
global_settings{
  assumed_gamma 1.0
  #if (use_rad)
    #include "rad_def.inc"
    radiosity{
      Rad_Settings(Radiosity_Fast, off, off)
    } 
  #end
}
#default{texture{finish{ambient 0 diffuse 1}}}


// *****************
// standard includes
// *****************
#include "colors.inc"
#include "textures.inc"


// ********
// sky dome
// ********
sphere{0,10e5
  pigment{White*.75+Turquoise*.25}
  finish{emission 1 diffuse 0}
  no_shadow
  hollow
  rotate 90*y
}


// ********
// sunlight
// ********
light_source{
  <0,10e4,0>,White*4
  #if (use_area)
    area_light 2000*x,2000*z,5,5 jitter adaptive 1 
  #end
  fade_power 0
  rotate <-40,80,0>
}


// **********************
// fake background forest
// **********************
plane{z,field_width
  hollow
  pigment{
    // http://mayang.com/textures/Plants/images/Trees/tropical_beach_flora_5160195.JPG
    image_map{jpeg "tropical_beach_flora_5160195.JPG" interpolate 2} 
    rotate 180*y
    translate -.5
    scale 50
    translate 9*y
  }
}

// **************
// bamboo texture
// **************
// dpigment to fade with aoi 
#declare p_aoi1=
pigment{
  granite 
  color_map{
    [0 rgb 1 transmit .5]
    [1 rgbt 1]
  }
  warp{turbulence .1 lambda 8}
}
// texture for the seams
#declare wm_t_bamboo1 = 
texture{
	pigment{
    // http://mayang.com/textures/Wood/images/Flat%20Wood%20Textures/light_wood_200145.JPG
    image_map{jpeg "light_wood_200145.JPG" interpolate 2}
    rotate 90*z
    scale field_width*.01*<1,15,1>
	}
}
// texture for the trunk sections, with the aoi layer on top
#declare wm_t_bamboo2 = 
texture{
  pigment{
    // http://mayang.com/textures/Plants/images/Leaves/banana_leaves_detail_234987234.JPG
    image_map{jpeg "banana_leaves_detail_234987234.JPG" interpolate 2}
    scale field_width*.02*12*<1,2,1>*2
    warp{turbulence .25 lambda 4}
    scale <1,1000,1>
	}
}
texture{
  pigment{
    aoi
    pigment_map{
      [0 p_aoi1]
      [1 rgbt 1]
    }
  }
}
// macro to mix both textures using a gradient
#macro wm_t_bamboo(disp)
texture{
  gradient y scale 1/6
  texture_map{
    [0 wm_t_bamboo1]
    [0.025 wm_t_bamboo2 translate disp]
    [0.5 wm_t_bamboo2 translate disp]
    [0.975 wm_t_bamboo2 translate disp]
    [1 wm_t_bamboo1]
  }
  scale 30 warp{turbulence .1 lambda 3} scale 1/30
}
#end

// ***************
// bamboo geometry
// ***************
// modeled with Wings3D and exported with Poseray
#include "i_bamboo2_POV_geom.inc"
// scatter some hundreds around with random placement
#declare r_grass=seed(295); 
#declare n_patches=200;
#declare i_patches=0;
#while (i_patches<n_patches)
  #declare grassl=<-field_width*.5+field_width*rand(r_grass),-1+2*rand(r_grass),-field_width*.5+field_width*rand(r_grass)>;
  #declare rr=1+rand(r_grass);
  #declare rl=.9+rand(r_grass)*.6;
  object{bamboo
    material{wm_t_bamboo(<1000*rand(r_grass),1000*rand(r_grass),1000*rand(r_grass)>)}
    scale 10*<rr,rl,rr>
    rotate (-5+10*rand(r_grass))*x
    rotate 360*rand(r_grass)*y
    rotate (-5+10*rand(r_grass))*z
    rotate 360*rand(r_grass)*y
    translate grassl  
  }
  #declare i_patches=i_patches+1;
#end


// ******
// camera
// ******
camera{ 
  location <2,0,-40>
  up <0, 1, 0> right <image_width/image_height, 0, 0>
  direction 3*z
  look_at <-1,0,0>
  #if (use_blur>0)
    aperture .33 blur_samples 7*use_blur focal_point <0,0,-field_width*.4>
  #end
}
